<?xml version="1.0"?>
<app>

<category>
Media Converter
</category>

<name>
Handbrake
</name>

<description>
   <am>versatile DVD ripper and video transcoder (cli and GUI)</am>
   <ar>versatile DVD ripper and video transcoder (cli and GUI)</ar>
   <bg>versatile DVD ripper and video transcoder (cli and GUI)</bg>
   <ca>gravador de DVDs i transcodificador de vídeo versàtil (IGU i consola)</ca>
   <cs>versatile DVD ripper and video transcoder (cli and GUI)</cs>
   <da>alsidig DVD-ripper og -videotranskoder (kommandolinje og grafisk brugerflade)</da>
   <de>Vielseitiger DVD-Ripper und Video-Transcoder (Cli und GUI)</de>
   <el>ευέλικτο DVD ripper και video transcoder (cli και GUI)</el>
   <en>versatile DVD ripper and video transcoder (cli and GUI)</en>
   <es>Versátil DVD ripper y transcodificador de vídeo (CLI y GUI)</es>
   <et>versatile DVD ripper and video transcoder (cli and GUI)</et>
   <eu>versatile DVD ripper and video transcoder (cli and GUI)</eu>
   <fa>versatile DVD ripper and video transcoder (cli and GUI)</fa>
   <fi>versatile DVD ripper and video transcoder (cli and GUI)</fi>
   <fr>Extracteur de DVD et transcodeur vidéo (cli and GUI)</fr>
   <he_IL>versatile DVD ripper and video transcoder (cli and GUI)</he_IL>
   <hi>versatile DVD ripper and video transcoder (cli and GUI)</hi>
   <hr>versatile DVD ripper and video transcoder (cli and GUI)</hr>
   <hu>versatile DVD ripper and video transcoder (cli and GUI)</hu>
   <id>versatile DVD ripper and video transcoder (cli and GUI)</id>
   <is>versatile DVD ripper and video transcoder (cli and GUI)</is>
   <it>versatile etrattore audio da DVD e transcoder video (CLI e GUI)</it>
   <ja_JP>versatile DVD ripper and video transcoder (cli and GUI)</ja_JP>
   <ja>versatile DVD ripper and video transcoder (cli and GUI)</ja>
   <kk>versatile DVD ripper and video transcoder (cli and GUI)</kk>
   <ko>versatile DVD ripper and video transcoder (cli and GUI)</ko>
   <lt>versatile DVD ripper and video transcoder (cli and GUI)</lt>
   <mk>versatile DVD ripper and video transcoder (cli and GUI)</mk>
   <nb>versatile DVD ripper and video transcoder (cli and GUI)</nb>
   <nl>veelzijdige DVD ripper en video transcoder (cli en GUI)</nl>
   <pl>wszechstronny ripper DVD i transkoder wideo (CLI i GUI)</pl>
   <pt_BR>versatile DVD ripper and video transcoder (cli and GUI)</pt_BR>
   <pt>Versátil extractor de dados de DVDs (DVD ripper) e transcodificador de vídeo (por consola e interface gáfica)</pt>
   <ro>versatile DVD ripper and video transcoder (cli and GUI)</ro>
   <ru>Многофункциональный DVD риппер и перекодировщик видео</ru>
   <sk>versatile DVD ripper and video transcoder (cli and GUI)</sk>
   <sl>versatile DVD ripper and video transcoder (cli and GUI)</sl>
   <sq>versatile DVD ripper and video transcoder (cli and GUI)</sq>
   <sr>versatile DVD ripper and video transcoder (cli and GUI)</sr>
   <sv>mångsidig DVD ripper och video transcoder (cli och GUI)</sv>
   <tr>versatile DVD ripper and video transcoder (cli and GUI)</tr>
   <uk>універсальний DVD витягувач та відео перетворювач (графічний та консольний)</uk>
   <zh_CN>versatile DVD ripper and video transcoder (cli and GUI)</zh_CN>
   <zh_TW>versatile DVD ripper and video transcoder (cli and GUI)</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/014/720/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
handbrake
handbrake-cli
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
handbrake
handbrake-cli
</uninstall_package_names>
</app>
